==> datapark-facade-1.2.22-sources.jar: com/bxm/datapark/facade/adpopup/model/vo/StayPopupPositionVo.java <==
package com.bxm.datapark.facade.adpopup.model.vo;

import java.io.Serializable;

/**
 * 挽留弹窗-广告位
 * @author zhounan
 * created on 2018/8/2
 */
public class StayPopupPositionVo implements Serializable ,CommonPopupAnalysisVo{

    /**
     * 弹窗名称
     */
    private String popupName;

    /**
     * 弹窗id
     */
    private String popupid;

    /**
     * 弹窗pv
     */
    private Integer popupPv;

    /**
     * 弹窗uv
     */
    private Integer popupUv;

    /**
     * 参与次数
     */
    private Integer joinPv;

    /**
     * 参与人数
     */
    private Integer joinUv;

    /**
     * 参与率
     */
    private double joinRate;

    /**
     * 发券量
     */
    private Integer openPv;

    /**
     * 人均发券
     */
    private double perOpenPv;

    /**
     * 重复发券
     */
    private double rptOpenPv;

    /**
     * 点击量
     */
    private Integer clickPv;

    /**
     * 点击率
     */
    private double clickRate;

    /**
     * 媒体名称
     */
    private String mediaName;

    /**
     * 广告位名称
     */
    private String positionName;

    /**
     * 广告位id
     */
    private String positionId;

    private String no;

    @Override
    public String getPopupName() {
        return popupName;
    }

    @Override
    public void setPopupName(String popupName) {
        this.popupName = popupName;
    }

    @Override
    public String getPopupid() {
        return popupid;
    }

    @Override
    public void setPopupid(String popupid) {
        this.popupid = popupid;
    }

    public Integer getPopupPv() {
        return popupPv;
    }

    public void setPopupPv(Integer popupPv) {
        this.popupPv = popupPv;
    }

    @Override
    public Integer getPopupUv() {
        return popupUv;
    }

    @Override
    public void setPopupUv(Integer popupUv) {
        this.popupUv = popupUv;
    }

    public Integer getJoinPv() {
        return joinPv;
    }

    public void setJoinPv(Integer joinPv) {
        this.joinPv = joinPv;
    }

    public Integer getJoinUv() {
        return joinUv;
    }

    public void setJoinUv(Integer joinUv) {
        this.joinUv = joinUv;
    }

    public double getJoinRate() {
        return joinRate;
    }

    public void setJoinRate(double joinRate) {
        this.joinRate = joinRate;
    }

    @Override
    public Integer getOpenPv() {
        return openPv;
    }

    @Override
    public void setOpenPv(Integer openPv) {
        this.openPv = openPv;
    }

    public double getPerOpenPv() {
        return perOpenPv;
    }

    public void setPerOpenPv(double perOpenPv) {
        this.perOpenPv = perOpenPv;
    }

    public double getRptOpenPv() {
        return rptOpenPv;
    }

    public void setRptOpenPv(double rptOpenPv) {
        this.rptOpenPv = rptOpenPv;
    }

    @Override
    public Integer getClickPv() {
        return clickPv;
    }

    @Override
    public void setClickPv(Integer clickPv) {
        this.clickPv = clickPv;
    }

    @Override
    public double getClickRate() {
        return clickRate;
    }

    @Override
    public void setClickRate(double clickRate) {
        this.clickRate = clickRate;
    }

    @Override
    public String getMediaName() {
        return mediaName;
    }

    @Override
    public void setMediaName(String mediaName) {
        this.mediaName = mediaName;
    }

    @Override
    public String getPositionName() {
        return positionName;
    }

    @Override
    public void setPositionName(String positionName) {
        this.positionName = positionName;
    }

    @Override
    public String getPositionId() {
        return positionId;
    }

    @Override
    public void setPositionId(String positionId) {
        this.positionId = positionId;
    }

    public String getNo() {
        return no;
    }

    public void setNo(String no) {
        this.no = no;
    }
}

==> datapark-facade-2.0.6-20190411.022157-1-sources.jar: com/bxm/datapark/facade/adpopup/model/vo/StayPopupPositionVo.java <==
package com.bxm.datapark.facade.adpopup.model.vo;

import java.io.Serializable;

/**
 * 挽留弹窗-广告位
 * @author zhounan
 * created on 2018/8/2
 */
public class StayPopupPositionVo implements Serializable ,CommonPopupAnalysisVo{

    private static final long serialVersionUID = 808743058522944184L;

    /**
     * 弹窗名称
     */
    private String popupName;

    /**
     * 弹窗id
     */
    private String popupid;

    /**
     * 弹窗pv
     */
    private Integer popupPv;

    /**
     * 弹窗uv
     */
    private Integer popupUv;

    /**
     * 参与次数
     */
    private Integer joinPv;

    /**
     * 参与人数
     */
    private Integer joinUv;

    /**
     * 参与率
     */
    private double joinRate;

    /**
     * 发券量
     */
    private Integer openPv;

    /**
     * 人均发券
     */
    private double perOpenPv;

    /**
     * 重复发券
     */
    private double rptOpenPv;

    /**
     * 点击量
     */
    private Integer clickPv;

    /**
     * 点击率
     */
    private double clickRate;

    /**
     * 媒体名称
     */
    private String mediaName;

    /**
     * 广告位名称
     */
    private String positionName;

    /**
     * 广告位id
     */
    private String positionId;

    private String no;
    
    /**
     * 媒体类型名称
     */
    private String mediaTypeName;

    /**
     * 媒体分类名称
     */
    private String mediaClass;

    /**
     * 媒体子分类名称
     */
    private String mediaChildClass;


    @Override
    public String getPopupName() {
        return popupName;
    }

    @Override
    public void setPopupName(String popupName) {
        this.popupName = popupName;
    }

    @Override
    public String getPopupid() {
        return popupid;
    }

    @Override
    public void setPopupid(String popupid) {
        this.popupid = popupid;
    }

    public Integer getPopupPv() {
        return popupPv;
    }

    public void setPopupPv(Integer popupPv) {
        this.popupPv = popupPv;
    }

    @Override
    public Integer getPopupUv() {
        return popupUv;
    }

    @Override
    public void setPopupUv(Integer popupUv) {
        this.popupUv = popupUv;
    }

    public Integer getJoinPv() {
        return joinPv;
    }

    public void setJoinPv(Integer joinPv) {
        this.joinPv = joinPv;
    }

    public Integer getJoinUv() {
        return joinUv;
    }

    public void setJoinUv(Integer joinUv) {
        this.joinUv = joinUv;
    }

    public double getJoinRate() {
        return joinRate;
    }

    public void setJoinRate(double joinRate) {
        this.joinRate = joinRate;
    }

    @Override
    public Integer getOpenPv() {
        return openPv;
    }

    @Override
    public void setOpenPv(Integer openPv) {
        this.openPv = openPv;
    }

    public double getPerOpenPv() {
        return perOpenPv;
    }

    public void setPerOpenPv(double perOpenPv) {
        this.perOpenPv = perOpenPv;
    }

    public double getRptOpenPv() {
        return rptOpenPv;
    }

    public void setRptOpenPv(double rptOpenPv) {
        this.rptOpenPv = rptOpenPv;
    }

    @Override
    public Integer getClickPv() {
        return clickPv;
    }

    @Override
    public void setClickPv(Integer clickPv) {
        this.clickPv = clickPv;
    }

    @Override
    public double getClickRate() {
        return clickRate;
    }

    @Override
    public void setClickRate(double clickRate) {
        this.clickRate = clickRate;
    }

    @Override
    public String getMediaName() {
        return mediaName;
    }

    @Override
    public void setMediaName(String mediaName) {
        this.mediaName = mediaName;
    }

    @Override
    public String getPositionName() {
        return positionName;
    }

    @Override
    public void setPositionName(String positionName) {
        this.positionName = positionName;
    }

    @Override
    public String getPositionId() {
        return positionId;
    }

    @Override
    public void setPositionId(String positionId) {
        this.positionId = positionId;
    }

    public String getNo() {
        return no;
    }

    public void setNo(String no) {
        this.no = no;
    }

    public String getMediaTypeName() {
        return mediaTypeName;
    }

    public void setMediaTypeName(String mediaTypeName) {
        this.mediaTypeName = mediaTypeName;
    }

    public String getMediaClass() {
        return mediaClass;
    }

    public void setMediaClass(String mediaClass) {
        this.mediaClass = mediaClass;
    }

    public String getMediaChildClass() {
        return mediaChildClass;
    }

    public void setMediaChildClass(String mediaChildClass) {
        this.mediaChildClass = mediaChildClass;
    }

}
